Date: 01 4, 2002 1:03:57 PM

# conceptpath

## Purpose

Fetch entire path of given concept as a string.

## Syntax

returnedString = conceptpath(concept)

returnedString - type: str
concept - type: con

## Returns

Path of concept as a string.

## Remarks

If the concept is bad, an error appears in the output log window.

## Example

G("childConcept") = makeconcept(makeconcept(findroot(), "parent"), "child");
"output.txt" << conceptpath(G("childConcept"));

Writes the following to output.txt:

"concept" "parent" "child"

## See Also

attrname, findwordpath, wordpath, Knowledge Base Functions